<?php

/* --------------------------------------------------------------
   LinkPageContentBuilderInterface.inc.php 2019-04-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Interface LinkPageContentBuilderInterface
 *
 * @category   System
 * @package    Content
 * @subpackage Interfaces
 */
interface LinkPageContentBuilderInterface
{
    /**
     * Set the page position
     *
     * @param PagePosition $position Page position
     *
     * @return LinkPageContentBuilder Same instance
     */
    public function inPosition(PagePosition $position);
    
    
    /**
     * Set the activation status
     *
     * @param ContentStatus $status Activation status
     *
     * @return LinkPageContentBuilder Same instance
     */
    public function usingStatus(ContentStatus $status);
    
    
    /**
     * Set the localized content titles
     *
     * @param ContentTitleCollection $titles Localized titles
     *
     * @return LinkPageContentBuilder Same instance
     */
    public function usingTitles(ContentTitleCollection $titles);
    
    
    /**
     * Set the localized content names
     *
     * @param ContentNameCollection $names Localized names
     *
     * @return LinkPageContentBuilder Same instance
     */
    public function usingNames(ContentNameCollection $names);
    
    
    /**
     * Set the localized content links
     *
     * @param ContentLinkCollection $links Localized links
     *
     * @return LinkPageContentBuilder Same instance
     */
    public function usingLinks(ContentLinkCollection $links);
    
    
    /**
     * Set whether the link page opens in a new tab
     *
     * @param ContentOpenInNewTabStatus $openInNewTabStatus Whether the link page opens in a new tab
     *
     * @return LinkPageContentBuilder Same instance
     */
    public function usingOpenInNewTabStatus(ContentOpenInNewTabStatus $openInNewTabStatus);
    
    
    /**
     * Set the content group id
     *
     * @param int|null $id
     *
     * @return InfoPageContentBuilder Same instance
     */
    public function usingId($id = null);
}